"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var methods_generator_1 = require("./methods.generator");
var utilities_1 = require("../utilities");
var types_generator_1 = require("./types.generator");
var query_generator_1 = require("./query.generator");
exports.createReactApolloHook = function (_a) {
    var field = _a.field, type = _a.type, renderedFragmentInner = _a.renderedFragmentInner;
    var hasArgs = field.args.length > 0;
    var methodName = field.name;
    var methodArgsType = methods_generator_1.createMethodsArgs(field).methodArgsType;
    var isScalar = utilities_1.evaluateType(field).isScalar;
    var returnedTypeDisplay = types_generator_1.getOneTSTypeDisplay({
        field: field,
    });
    var typeNameLower = type;
    var typeNameUpper = utilities_1.capitalizeFirstLetter(type);
    var Query = query_generator_1.queryBuilder({
        field: field,
        isScalar: isScalar,
        renderedFragmentInner: renderedFragmentInner,
        type: type,
    });
    var TOptions = "{" + methodName + ": " + returnedTypeDisplay + "}" + (hasArgs ? ', ' + methodArgsType : '');
    var useHookOutput = "return use" + typeNameUpper + "<" + TOptions + ">(" + typeNameLower + ", options);";
    if (isScalar) {
        return "\n    " + (field.description ? "/** " + field.description + " */" : '') + "\n    export const use" + utilities_1.capitalizeFirstLetter(field.name) + " = (options?: " + typeNameUpper + "HookOptions<" + TOptions + ">) =>  {\n      const " + typeNameLower + " = " + Query + "\n      " + useHookOutput + "\n    },";
    }
    else {
        return "\n    " + (field.description ? "/** " + field.description + " */" : '') + "\n    export const use" + utilities_1.capitalizeFirstLetter(field.name) + " = (fragment: string | DocumentNode, options?: " + typeNameUpper + "HookOptions<" + TOptions + ">) => {\n      const { isString, isFragment, fragmentName } = guessFragmentType(fragment);\n      const " + typeNameLower + " = " + Query + "\n\n      " + useHookOutput + "\n    }\n  ,";
    }
};
exports.createVueApolloHook = function (_a) {
    var field = _a.field, type = _a.type, renderedFragmentInner = _a.renderedFragmentInner;
    var hasArgs = field.args.length > 0;
    var methodName = field.name;
    var methodArgsType = methods_generator_1.createMethodsArgs(field).methodArgsType;
    var isScalar = utilities_1.evaluateType(field).isScalar;
    var returnedTypeDisplay = types_generator_1.getOneTSTypeDisplay({
        field: field,
    });
    var typeNameLower = type;
    var typeNameUpper = utilities_1.capitalizeFirstLetter(type);
    var Query = query_generator_1.queryBuilder({
        field: field,
        isScalar: isScalar,
        renderedFragmentInner: renderedFragmentInner,
        type: type,
    });
    var TOptions = "Use" + typeNameUpper + "Options<{" + methodName + ": " + returnedTypeDisplay + "}" + (hasArgs ? ', ' + methodArgsType : '') + ">";
    var vueApolloParams = "variables?: " + methodArgsType + " | Ref<" + methodArgsType + "> | ReactiveFunction<" + methodArgsType + ">, options?: " + TOptions + " | Ref<" + TOptions + "> | ReactiveFunction<" + TOptions + ">";
    var useHookOutput = "return use" + typeNameUpper + "<" + TOptions + ">(" + typeNameLower + ", variables, options);";
    if (isScalar) {
        return "\n    " + (field.description ? "/** " + field.description + " */" : '') + "\n    export const use" + utilities_1.capitalizeFirstLetter(field.name) + " = (" + vueApolloParams + ") =>  {\n      const " + typeNameLower + " = " + Query + "\n      " + useHookOutput + "\n    }";
    }
    else {
        return "\n    " + (field.description ? "/** " + field.description + " */" : '') + "\n    export const use" + utilities_1.capitalizeFirstLetter(field.name) + " = (fragment: string | DocumentNode, " + vueApolloParams + ") => {\n      const { isString, isFragment, fragmentName } = guessFragmentType(fragment);\n      const " + typeNameLower + " = " + Query + "\n\n      " + useHookOutput + "\n    }";
    }
};
